<?php

if( ! class_exists('ph_shipping_rate_adjustment_processor') ) {

	class ph_shipping_rate_adjustment_processor {

		var $settings;

		public function __construct() {

			$this->settings = get_option('ph_shipping_rate_adjustment_rate_adjustment');

			$this->and_logic = isset($this->settings['logic_section']) && isset($this->settings['logic_section']['and_logic']) ?  $this->settings['logic_section']['and_logic'] : false;

			add_filter( 'woocommerce_package_rates', array($this,'add_rate_adjustment_for_shipping_methods'), 11, 2);
		}

		public function add_rate_adjustment_for_shipping_methods($available_shipping_methods, $package){

			$cart_shipping_classes = $this->ph_get_all_cart_shipping_classes($package);
			
			$filtered_row 	= $this->ph_filter_rate_adjustment_rows( $cart_shipping_classes );

			// Filter the First Matched Rule
			$filtered_row = !empty($filtered_row) && isset($filtered_row[0]) ?  array($filtered_row[0]) : array();

			if( !empty($filtered_row) ) {

				$available_shipping_methods = $this->ph_process_filtered_row($filtered_row , $available_shipping_methods, $package );
			}
			
			return $available_shipping_methods; 
		}

		public function ph_process_filtered_row($filtered_row, $available_shipping_methods, $package = array() ) {

			$shipping_methods 	= array();

			foreach( $filtered_row as $key => $rule ) {

				if( !empty($rule['fixed_adjustment']) || !empty($rule['percent_adjustment']) ) {

					$shipping_methods[$key] = [];

					if( empty($rule['shipping_method']) ) {

						$methods = explode( ';', trim($rule['shipping_method_id']) );

						$methods = array_map( function($method) { return trim($method); }, $methods );
						
						$shipping_methods[$key]['method'] 	= $methods;
						$shipping_methods[$key]['fixed'] 	= $rule['fixed_adjustment'];
						$shipping_methods[$key]['percent'] 	= $rule['percent_adjustment'];

					}else{

						$methods = explode( ';', trim($rule['shipping_method']) );

						$methods = array_map( function($method) { return trim($method); }, $methods );

						$shipping_methods[$key]['method'] 	= $methods;
						$shipping_methods[$key]['fixed'] 		= $rule['fixed_adjustment'];
						$shipping_methods[$key]['percent'] 	= $rule['percent_adjustment'];
					}
				}
			}

			if( !empty($shipping_methods) ) {

				foreach ($shipping_methods as $shipping_method) {
					
					$available_shipping_methods = $this->ph_add_shipping_method_adjustment_rate( $available_shipping_methods, $shipping_method['method'], $shipping_method['fixed'], $shipping_method['percent'] );
				}
			}

			return $available_shipping_methods;
		}

		private function ph_add_shipping_method_adjustment_rate( $available_shipping_methods, $rule_methods, $fixed_cost, $percentage_cost ) {

			foreach ($available_shipping_methods as $shipping_method => $method_data) {

				$method 	= $method_data->get_id();
				$method_id 	= $method_data->get_method_id();
				$final_cost = $available_shipping_methods[$shipping_method]->cost;

				if( in_array($method_id, $rule_methods) || in_array($method, $rule_methods) ) {

					if( !empty($percentage_cost) ) {

						$final_cost = $final_cost + ( $final_cost * round( ( $percentage_cost / 100 ), 2 ) );
					}

					if( !empty($fixed_cost) ) {

						$final_cost = $fixed_cost + $final_cost;
					}
				}

				$available_shipping_methods[$shipping_method]->cost = $final_cost;

			}

			return $available_shipping_methods;
		}

		public function ph_filter_rate_adjustment_rows( $cart_shipping_classes ) {
			
			$matching_row = array();

			if( isset($this->settings['adjustment_section']) && !empty($this->settings['adjustment_section']) ) {

				foreach( $this->settings['adjustment_section'] as $row_num => $row ) {

					$rule_shipping_classes = isset($row['shipping_class']) ? $row['shipping_class'] : array();

					if( empty($rule_shipping_classes) ) {

						$matching_row[] = $row;
					} else {

						if ( $this->and_logic ) {

							$matched_classes = array_intersect($rule_shipping_classes,$cart_shipping_classes);
							
							$matched_count 	= count($matched_classes);
							$cart_count 	= count($cart_shipping_classes);
							$rule_count 	= count($rule_shipping_classes);

							if( !empty($matched_classes) && $matched_count == $cart_count && $matched_count == $rule_count ) {

								$matching_row[] = $row;
							}

						} else {

							$matched_classes = array_intersect($rule_shipping_classes,$cart_shipping_classes);

							if( !empty($matched_classes) ) {

								$matching_row[] = $row;
							}
						}
						
					}
				}
			}

			return $matching_row;
		}

		public function ph_get_all_cart_shipping_classes( $package=array() ) {

			$shipping_class_in_cart = array();

			foreach( $package['contents'] as $key => $values) {

				if( isset($values['data']) && is_object($values['data']) && $values['data']->needs_shipping() ) {

					$shipping_class_in_cart[] = $values['data']->get_shipping_class();
				}
			}

			return $shipping_class_in_cart;
		}
	}

	new ph_shipping_rate_adjustment_processor;
}