<?php
/*
Plugin Name: WooCommerce Shipping Rate Adjustment
Description: This plugin allows you to adjust shipping cost by a percentage or a fixed amount based on Shipping Classes.
Version: 1.0
Author: PluginHive
Author URI: https://www.pluginhive.com/about/
Text Domain: ph-wc-shipping-rate-adjustment
*/

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}	

function ph_shipping_rate_adjustment_required_plugins() {

	$ph_addon_required_plugins 	= false;

	$active_plugins = apply_filters( 'active_plugins', get_option( 'active_plugins', array() ) );

	// Multisite case
	if ( is_multisite() ) {
		$active_plugins = array_merge( $active_plugins, array_keys( get_site_option( 'active_sitewide_plugins', array() ) ) );
	}

	if ( in_array( 'woocommerce/woocommerce.php', $active_plugins ) ) {

		$ph_addon_required_plugins = true;
	}

	return $ph_addon_required_plugins;
}

// Auto Deactivate
add_action( 'admin_init', 'ph_shipping_rate_adjustment_deactivate' );

if ( ! function_exists( 'ph_shipping_rate_adjustment_deactivate' ) ) {
	function ph_shipping_rate_adjustment_deactivate() {

		$ph_required_plugins 	= ph_shipping_rate_adjustment_required_plugins();

		if ( !$ph_required_plugins ) {

			deactivate_plugins( plugin_basename( __FILE__ ) );
			wp_safe_redirect( admin_url('plugins.php') );
		}
	}
}

function ph_shipping_rate_adjustment_activation_check(){

	$ph_required_plugins 	= ph_shipping_rate_adjustment_required_plugins();

	if ( !$ph_required_plugins ) {

		deactivate_plugins( basename( __FILE__ ) );
		wp_die( __("Oops! You tried installing the WooCommerce Shipping Rate Adjustment without activating WooCommerce Plugin. Kindly activate <b>WooCommerce Plugin</b> and then try again", "ph-wc-shipping-rate-adjustment" ), "", array('back_link' => 1 ));
	}
}

register_activation_hook( __FILE__, 'ph_shipping_rate_adjustment_activation_check' );

if ( ! class_exists( 'PH_WC_Shipping_Rate_Adjustment_Addon' ) ) {

	class PH_WC_Shipping_Rate_Adjustment_Addon {

		public function __construct() {

			add_action( 'woocommerce_get_settings_pages',array($this, 'ph_get_shipping_rate_adjustment_settings') );

			$this->ph_shipping_rate_adjustment_addon();

			add_filter( 'plugin_action_links_' . plugin_basename( __FILE__ ), array( $this, 'ph_shipping_rate_adjustment_plugin_action_links' ) );
		}
		
		public function ph_shipping_rate_adjustment_get_settings_url() {

			return version_compare(WC()->version, '1.0', '>=') ? "wc-settings" : "woocommerce_settings";
		}

		public function ph_shipping_rate_adjustment_plugin_action_links( $links ) {

			$plugin_links = array(
				'<a href="' . admin_url( 'admin.php?page=' . $this->ph_shipping_rate_adjustment_get_settings_url() . '&tab=ph_shipping_rate_adjustment' ) . '">' . __( 'Settings', 'ph-wc-shipping-rate-adjustment' ) . '</a>',

			);

			return array_merge( $plugin_links, $links );
		}

		public function ph_get_shipping_rate_adjustment_settings( $settings = array() ) {

			include_once( 'includes/class-shipping-rate-adjustment-settings.php' );

			return $settings;
		}

		public function ph_shipping_rate_adjustment_addon() {

			include_once( 'includes/class-shipping-rate-adjustment-processor.php' );
		}

	}

	new PH_WC_Shipping_Rate_Adjustment_Addon();
}